Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(87)

Unified Diff: chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc

Issue 2026213002: Refactor CertificateReportSender (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ssl/chrome_expect_ct_reporter.cc ('k') | components/certificate_reporting/error_reporter.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc
diff --git a/chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc b/chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc
index cc1561b054a40dec6442d031861345f001583d81..98e78ddecf39be40a2217c7f32d2896a62c3cc17 100644
--- a/chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc
+++ b/chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc
@@ -19,7 +19,7 @@
#include "net/ssl/signed_certificate_timestamp_and_status.h"
#include "net/test/cert_test_util.h"
#include "net/test/url_request/url_request_failed_job.h"
-#include "net/url_request/certificate_report_sender.h"
+#include "net/url_request/report_sender.h"
#include "net/url_request/url_request_filter.h"
#include "net/url_request/url_request_test_util.h"
#include "testing/gtest/include/gtest/gtest.h"
@@ -30,14 +30,12 @@ namespace {
const char kSendHistogramName[] = "SSL.ExpectCTReportSendingAttempt";
const char kFailureHistogramName[] = "SSL.ExpectCTReportFailure";
// A test CertificateReportSender that exposes the latest report URI and
// serialized report to be sent.
-class TestCertificateReportSender : public net::CertificateReportSender {
+class TestCertificateReportSender : public net::ReportSender {
public:
TestCertificateReportSender()
- : CertificateReportSender(
- nullptr,
- net::CertificateReportSender::DO_NOT_SEND_COOKIES) {}
+ : ReportSender(nullptr, net::ReportSender::DO_NOT_SEND_COOKIES) {}
~TestCertificateReportSender() override {}
void Send(const GURL& report_uri,
« no previous file with comments | « chrome/browser/ssl/chrome_expect_ct_reporter.cc ('k') | components/certificate_reporting/error_reporter.h » ('j') | no next file with comments »
@@ -30,14 +30,12 @@ namespace {
const char kSendHistogramName[] = "SSL.ExpectCTReportSendingAttempt";
const char kFailureHistogramName[] = "SSL.ExpectCTReportFailure";
-// A test CertificateReportSender that exposes the latest report URI and
+// A test ReportSender that exposes the latest report URI and
// serialized report to be sent.

Powered by Google App Engine
This is Rietveld 408576698